==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/VirtualCallSite.h <==
// public class soot.jimple.toolkits.callgraph.VirtualCallSite

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c2dd5ab272ded44 soot_jimple_toolkits_callgraph_VirtualCallSite

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_
#define _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InstanceInvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$_init$85b241d8eed141e7(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getContainer$d5fac1b00d60c436(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getInstanceInvokeExpr$55ca270e9171ccdf(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getStmt$5e6b0a6d37e9a94d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getContainer$d5fac1b00d60c436;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getInstanceInvokeExpr$55ca270e9171ccdf;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getStmt$5e6b0a6d37e9a94d;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods {
	struct _jc_soot_SootMethod$object	*(*getContainer$d5fac1b00d60c436)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);
	struct _jc_object	*(*getInstanceInvokeExpr$55ca270e9171ccdf)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);
	struct _jc_object	*(*getStmt$5e6b0a6d37e9a94d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods	soot_jimple_toolkits_callgraph_VirtualCallSite;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs {
	struct _jc_object	*iie;
	struct _jc_object	*stmt;
	struct _jc_soot_SootMethod$object	*container;
	struct _jc_soot_util_NumberedString$object	*subSig;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs {
    _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs	soot_jimple_toolkits_callgraph_VirtualCallSite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs	soot_jimple_toolkits_callgraph_VirtualCallSite;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object {
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_VirtualCallSite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/VirtualCallSite.h <==
// public class soot.jimple.toolkits.callgraph.VirtualCallSite

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c2dd5ab272ded44 soot_jimple_toolkits_callgraph_VirtualCallSite

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_
#define _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InstanceInvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$_init$85b241d8eed141e7(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getContainer$d5fac1b00d60c436(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getInstanceInvokeExpr$55ca270e9171ccdf(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method$getStmt$5e6b0a6d37e9a94d(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getContainer$d5fac1b00d60c436;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getInstanceInvokeExpr$55ca270e9171ccdf;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$method_info$getStmt$5e6b0a6d37e9a94d;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods {
	struct _jc_soot_SootMethod$object	*(*getContainer$d5fac1b00d60c436)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getInstanceInvokeExpr$55ca270e9171ccdf)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getStmt$5e6b0a6d37e9a94d)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vmethods	soot_jimple_toolkits_callgraph_VirtualCallSite;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs {
	struct _jc_object	*iie;
	struct _jc_object	*stmt;
	struct _jc_soot_SootMethod$object	*container;
	struct _jc_soot_util_NumberedString$object	*subSig;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs {
    _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_refs	soot_jimple_toolkits_callgraph_VirtualCallSite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$sub_nonrefs	soot_jimple_toolkits_callgraph_VirtualCallSite;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$object {
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_VirtualCallSite$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$vtype _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_VirtualCallSite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_VirtualCallSite$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_VirtualCallSite_H_ */
